==> pybirdsreynolds-1.99.2.tar.gz: pybirdsreynolds-1.99.2/pybirdsreynolds/const.py <==
HEIGHT_PARAMS_DEFAULT=500
WIDTH_PARAMS_DEFAULT=400
NUM_BIRDS_DOC="Number of birds"
NUM_BIRDS_DEFAULT=500
NUM_BIRDS_MIN=1
NUM_BIRDS_MAX=1000
NUM_BIRDS_FREE_MIN=1
NUM_BIRDS_FREE_MAX=None
COH_WEIGHT_DOC="Cohesion weight"
COH_WEIGHT_DEFAULT=1
COH_WEIGHT_MIN=0
COH_WEIGHT_MAX=10
COH_WEIGHT_FREE_MIN=None
COH_WEIGHT_FREE_MAX=None
ALIGN_WEIGHT_DOC="Alignment weight"
ALIGN_WEIGHT_DEFAULT=2
ALIGN_WEIGHT_MIN=0
ALIGN_WEIGHT_MAX=10
ALIGN_WEIGHT_FREE_MIN=None
ALIGN_WEIGHT_FREE_MAX=None
SEP_WEIGHT_DOC="Separation weight"
SEP_WEIGHT_DEFAULT=3
SEP_WEIGHT_MIN=0
SEP_WEIGHT_MAX=10
SEP_WEIGHT_FREE_MIN=None
SEP_WEIGHT_FREE_MAX=None
NEIGHBOR_RADIUS_DOC="Distance to detect neighbors"
NEIGHBOR_RADIUS_DEFAULT=50
NEIGHBOR_RADIUS_MIN=0
NEIGHBOR_RADIUS_MAX=None
NEIGHBOR_RADIUS_FREE_MIN=0
WIDTH_DOC="Area width"
WIDTH_DEFAULT=1000
WIDTH_MIN=200
WIDTH_MAX=None
WIDTH_FREE_MIN=200
WIDTH_FREE_MAX=None
HEIGHT_DOC="Area height"
HEIGHT_DEFAULT=500
HEIGHT_MIN=500
HEIGHT_MAX=None
HEIGHT_FREE_MIN=500
HEIGHT_FREE_MAX=None
NEIGHBOR_RADIUS_FREE_MAX=None
MAX_SPEED_DOC="Maximum speed of birds"
MAX_SPEED_DEFAULT=10
MAX_SPEED_MIN=0
MAX_SPEED_MAX=100
MAX_SPEED_FREE_MIN=0
MAX_SPEED_FREE_MAX=100
RANDOM_SPEED_DOC="Random speed variation ratio in percentage"
RANDOM_SPEED_DEFAULT=0
RANDOM_SPEED_MIN=0
RANDOM_SPEED_MAX=10
RANDOM_SPEED_FREE_MIN=0
RANDOM_SPEED_FREE_MAX=None
RANDOM_ANGLE_DOC="Random angle variation in degrees"
RANDOM_ANGLE_DEFAULT=0
RANDOM_ANGLE_MIN=0
RANDOM_ANGLE_MAX=10
RANDOM_ANGLE_FREE_MIN=None
RANDOM_ANGLE_FREE_MAX=None
# REFRESH_MS_DOC="Refresh interval in milliseconds"
REFRESH_MS_DEFAULT=10
# REFRESH_MS_MIN=10
# REFRESH_MS_MAX=100
# REFRESH_MS_FREE_MIN=None
# REFRESH_MS_FREE_MAX=None
# SIZE_DOC="Visual size of birds"
SIZE_DEFAULT=2
# SIZE_MIN=1
# SIZE_MAX=3
# SIZE_FREE_MIN=1
# SIZE_FREE_MAX=None
#FONT_SIZE_DOC="Font Size"
FONT_SIZE_DEFAULT=12
FONT_SIZE_MIN=6
FONT_SIZE_MAX=12
FONT_SIZE_FREE_MIN=6
FONT_SIZE_FREE_MAX=12
# TRIANGLES_DOC="Render birds as triangles instead of points"
TRIANGLES_DEFAULT=False
# COLOR_DOC="Enable colors"
COLOR_DEFAULT=False
FONT_TYPE_DEFAULT="Nota Sans Mono"
#FONT_TYPE_DOC="Font"
FONT_TYPE_LIST=["Nota Sans Mono", "Consolas", "Courier"]
FREE_DOC="Remove parameter limits"
FREE_DEFAULT=False
COMMON_CONTROLS = [
    "   Toggle start / stop [Space] ",
    "   Reset all params [r] ",
    "   New generation of birds [n] ",
    "   Toggle FPS display [f] "
]

==> pybirdsreynolds-1.99.20.tar.gz: pybirdsreynolds-1.99.20/pybirdsreynolds/const.py <==
SHORT_DESCRIPTION="pybirdsreynolds is an interactive simulation of the Reynolds Boids model."
HEIGHT_PARAMS_CONTROLS_DEFAULT=400
WIDTH_CONTROLS_DEFAULT=70
WIDTH_PARAMS_DEFAULT=300
NUM_BIRDS_DOC="Number of birds"
NUM_BIRDS_DEFAULT=400
NUM_BIRDS_MIN=1
NUM_BIRDS_MAX=1000
NUM_BIRDS_FREE_MIN=1
NUM_BIRDS_FREE_MAX=None
COH_WEIGHT_DOC="Cohesion weight"
COH_WEIGHT_DEFAULT=1
COH_WEIGHT_MIN=0
COH_WEIGHT_MAX=10
COH_WEIGHT_FREE_MIN=None
COH_WEIGHT_FREE_MAX=None
ALIGN_WEIGHT_DOC="Alignment weight"
ALIGN_WEIGHT_DEFAULT=2
ALIGN_WEIGHT_MIN=0
ALIGN_WEIGHT_MAX=10
ALIGN_WEIGHT_FREE_MIN=None
ALIGN_WEIGHT_FREE_MAX=None
SEP_WEIGHT_DOC="Separation weight"
SEP_WEIGHT_DEFAULT=3
SEP_WEIGHT_MIN=0
SEP_WEIGHT_MAX=10
SEP_WEIGHT_FREE_MIN=None
SEP_WEIGHT_FREE_MAX=None
NEIGHBOR_RADIUS_DOC="Distance to detect neighbors"
NEIGHBOR_RADIUS_DEFAULT=50
NEIGHBOR_RADIUS_MIN=0
NEIGHBOR_RADIUS_MAX=None
NEIGHBOR_RADIUS_FREE_MIN=0
WIDTH_DOC="Area width"
WIDTH_DEFAULT=1000
WIDTH_MIN=200
WIDTH_MAX=None
WIDTH_FREE_MIN=200
WIDTH_FREE_MAX=None
HEIGHT_DOC="Area height"
HEIGHT_DEFAULT=500
HEIGHT_MIN=400
HEIGHT_MAX=None
HEIGHT_FREE_MIN=400
HEIGHT_FREE_MAX=None
NEIGHBOR_RADIUS_FREE_MAX=None
MAX_SPEED_DOC="Maximum speed of birds"
MAX_SPEED_DEFAULT=10
MAX_SPEED_MIN=0
MAX_SPEED_MAX=100
MAX_SPEED_FREE_MIN=0
MAX_SPEED_FREE_MAX=100
RANDOM_SPEED_DOC="Random speed variation ratio in percentage"
RANDOM_SPEED_DEFAULT=0
RANDOM_SPEED_MIN=0
RANDOM_SPEED_MAX=10
RANDOM_SPEED_FREE_MIN=0
RANDOM_SPEED_FREE_MAX=None
RANDOM_ANGLE_DOC="Random angle variation in degrees"
RANDOM_ANGLE_DEFAULT=0
RANDOM_ANGLE_MIN=0
RANDOM_ANGLE_MAX=10
RANDOM_ANGLE_FREE_MIN=None
RANDOM_ANGLE_FREE_MAX=None
REFRESH_MS_DOC="Refresh interval in milliseconds"
REFRESH_MS_DEFAULT=10
REFRESH_MS_MIN=1
REFRESH_MS_MAX=100
REFRESH_MS_FREE_MIN=1
REFRESH_MS_FREE_MAX=None
#SIZE_DOC="Visual size of birds"
SIZE_DEFAULT=2
SIZE_MIN=1
SIZE_MAX=3
SIZE_FREE_MIN=1
SIZE_FREE_MAX=None
#TRIANGLES_DOC="Render birds as triangles instead of points"
TRIANGLES_DEFAULT=False
#COLOR_DOC="Enable colors"
COLOR_DEFAULT=False
FONT_TYPE_DEFAULT="Nota Sans Mono"
#FONT_TYPE_DOC="Font"
FONT_TYPE_LIST=["Nota Sans Mono", "Consolas", "Courier"]
FREE_DOC="Remove parameter limits"
#FONT_SIZE_DOC="Font Size"
FONT_SIZE_DEFAULT=12
FONT_SIZE_MIN=6
FONT_SIZE_MAX=12
FONT_SIZE_FREE_MIN=6
FONT_SIZE_FREE_MAX=12
FREE_DEFAULT=False
TOOGLE_START_PAUSE_ICON="⏯"
TOOGLE_START_PAUSE_TEXT="Toggle start / stop"
TOOGLE_START_PAUSE_COMMAND='p'
RESET_ICON="⟳"
RESET_TEXT="Reset all params"
RESET_COMMAND='r'
REGENERATION_ICON="🪶"
REGENERATION_COMMAND='b'
REGENERATION_TEXT="New generation of birds"
TOOGLE_FPS_ICON="⏱"
TOOGLE_FPS_TEXT="Toggle FPS display"
TOOGLE_FPS_COMMAND='f'
NEXT_FRAME_ICON = "⏭"
NEXT_FRAME_TEXT="Next frame"
NEXT_FRAME_COMMAND='n'
TOOGLE_MAXIMIZE_ICON = "🗖"
TOOGLE_MAXIMIZE_TEXT="Maximize/Minimize"
TOOGLE_MAXIMIZE_COMMAND='m'
HIDE_ICON="👁"
HIDE_TEXT="Hide Params and Controls"
HIDE_COMMAND='h'
